@@ -40,7 +40,8 @@ def value_from_markers(key, request):
 
 def ccd_data(data_size=DEFAULT_DATA_SIZE,
              data_scale=DEFAULT_DATA_SCALE,
-             data_mean=DEFAULT_DATA_MEAN):
+             data_mean=DEFAULT_DATA_MEAN,
+             rng_seed=DEFAULT_SEED):
     """
     Return a CCDData object with units of ADU.
 
@@ -61,7 +62,7 @@ def ccd_data(data_size=DEFAULT_DATA_SIZE,
     scale = data_scale
     mean = data_mean
 
-    with NumpyRNGContext(DEFAULTS['seed']):
+    with NumpyRNGContext(rng_seed):
         data = np.random.normal(loc=mean, size=[size, size], scale=scale)
 
     fake_meta = {'my_key': 42, 'your_key': 'not 42'}
