@@ -1,9 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+from packaging.version import Version, parse
 
 import numpy as np
 
 import astropy.units as u
 from astropy.stats import median_absolute_deviation as mad
+import astropy
 
 import pytest
 from astropy.utils.data import get_pkg_data_filename
@@ -14,6 +16,15 @@ from ccdproc.combiner import (Combiner, combine, _calculate_step_sizes,
 from ccdproc.image_collection import ImageFileCollection
 from ccdproc.tests.pytest_fixtures import ccd_data as ccd_data_func
 
+SUPER_OLD_ASTROPY = parse(astropy.__version__) < Version('4.3.0')
+
+# Several tests have many more NaNs in them than real data. numpy generates
+# lots of warnings in those cases and it makes more sense to suppress them
+# than to generate them.
+pytestmark = pytest.mark.filterwarnings(
+    'ignore:All-NaN slice encountered:RuntimeWarning'
+)
+
 
 # test that the Combiner raises error if empty
 def test_combiner_empty():
@@ -299,15 +310,23 @@ def test_combiner_sum_weighted_by_pixel():
     np.testing.assert_almost_equal(ccd, expected_result)
 
 
-# test data combined with mask is created correctly
+# This warning is generated by numpy and is expected when
+# many pixels are masked.
+@pytest.mark.filterwarnings(
+    'ignore:Mean of empty slice:RuntimeWarning',
+    'ignore:Degrees of freedom <= 0:RuntimeWarning'
+)
 def test_combiner_mask_average():
+    # test data combined with mask is created correctly
     data = np.zeros((10, 10))
     data[5, 5] = 1
     mask = (data == 0)
     ccd = CCDData(data, unit=u.adu, mask=mask)
     ccd_list = [ccd, ccd, ccd]
     c = Combiner(ccd_list)
+
     ccd = c.average_combine()
+
     # How can we assert anything about the data if all values
     # are masked?!
     # assert ccd.data[0, 0] == 0
@@ -369,8 +388,12 @@ def test_combiner_mask_median():
     assert not ccd.mask[5, 5]
 
 
-# test data combined with mask is created correctly
+# Ignore warnings generated because most values are masked
+@pytest.mark.filterwarnings(
+    'ignore:Degrees of freedom <= 0:RuntimeWarning'
+)
 def test_combiner_mask_sum():
+    # test data combined with mask is created correctly
     data = np.zeros((10, 10))
     data[5, 5] = 1
     mask = (data == 0)
@@ -573,6 +596,11 @@ def test_sum_combine_uncertainty():
         ccd.uncertainty.array, ccd2.uncertainty.array)
 
 
+# Ignore warnings generated because most values are masked
+@pytest.mark.filterwarnings(
+    'ignore:Mean of empty slice:RuntimeWarning',
+    'ignore:Degrees of freedom <= 0:RuntimeWarning'
+)
 @pytest.mark.parametrize('mask_point', [True, False])
 @pytest.mark.parametrize('comb_func',
                          ['average_combine', 'median_combine', 'sum_combine'])
